macro_rules! unit { ($description:expr) => { ... }; }
Check if a value not equal to an another
descriptionThe unit descriptionitemsA vector contening all valuesvThe actual value to check unequality
macro_rules! unit { ($description:expr) => { ... }; }
description The unit descriptionitems A vector contening all valuesv The actual value to check unequality